@@ -1,6 +1,6 @@
 #!/usr/bin/python -i
 # DFF -- An Open Source Digital Forensics Framework
-# Copyright (C) 2009-2011 ArxSys
+# Copyright (C) 2009-2013 ArxSys
 # This program is free software, distributed under the terms of
 # the GNU General Public License Version 2. See the LICENSE file
 # at the top of the source tree.
@@ -19,26 +19,24 @@ Digital-forensic framework launcher
 """
 import os, sys, getopt
 
-if os.name == "posix": 
-    try :
-        import dl
-        sys.setdlopenflags(sys.getdlopenflags() | dl.RTLD_GLOBAL)
-    except ImportError:
-        import ctypes
-        sys.setdlopenflags(sys.getdlopenflags() | ctypes.RTLD_GLOBAL)
+from dff.api.manager.manager import ApiManager
 
-from api.manager.manager import ApiManager
-from ui.ui import ui, usage
+from dff.ui.gui.gui import GUI
+from dff.ui.console.console import Console
+from dff.ui.ui import Usage
+
+MODULES_PATHS = ["dff/modules"]
 
 def fg():
     """Launch shell loop"""
-    global ui
-    ui.c.cmdloop()
+    ui.launch()
 
 if __name__ == "__main__":
     """You can place some script command here for testing purpose"""
-    argv = usage(sys.argv[1:])
-    ui = ui('gui', argv.debug)
-    if argv.batch != None:
-       ui.cmd("batch " + argv.batch)
-    ui.launch()
+    argv = Usage(sys.argv[1:])
+    if argv.batch:
+       console = Console(debug=argv.debug, verbosity=argv.verbosity)
+       console.loadModules(MODULES_PATHS)
+       console.onecmd("batch " + argv.batch, False)
+    ui = GUI(argv.debug, argv.verbosity)
+    ui.launch(MODULES_PATHS)
